==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Image/Gui/Resources/translations/Image_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <source>Create image plane...</source>
      <translation>Napravi ravninu slike ...</translation>
    </message>
    <message>
      <source>Create a planar image in the 3D space</source>
      <translation>Napravi planarnu sliku u 3D prostoru</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>stvoriti planarnu sliku u 3D prikazu</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <source>Open...</source>
      <translation>Otvori ...</translation>
    </message>
    <message>
      <source>Open image view</source>
      <translation>Otvori pogled slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+318"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>nedefinirani tip boja za gledanje slika</translation>
    </message>
    <message>
      <source>Image pixel format</source>
      <translation>format slike u pixelima</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>Prilagodi sliku</translation>
    </message>
    <message>
      <source>Stretch the image to fit the view</source>
      <translation>rastegni sliku da odgovara prikazu</translation>
    </message>
    <message>
      <source>&amp;1:1 scale</source>
      <translation>u mjerilu 1:1</translation>
    </message>
    <message>
      <source>Display the image at a 1:1 scale</source>
      <translation>Prikaz slike u mjerilu 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation> I originalna boja</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Prikaži sliku s originalnim bojama</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>I  Razvedri boju</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Prikaži sliku s s izbjeljenim bojama</translation>
    </message>
    <message>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <source>Ready...</source>
      <translation>Spreman...</translation>
    </message>
    <message>
      <source>grey</source>
      <translation>siva</translation>
    </message>
    <message>
      <source>zoom</source>
      <translation>zum</translation>
    </message>
    <message>
      <source>outside image</source>
      <translation>izvan slike</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Pregled slike</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+106"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Slike (*. png *. XPM *. jpg *. bmp)</translation>
    </message>
    <message>
      <source>Choose an image file to open</source>
      <translation>Odaberite koju ce te sliku otvoriti</translation>
    </message>
    <message>
      <source>Images</source>
      <translation>Slike</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>Sve datoteke</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Pogreška pri otvaranju slike</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nije moguće učitati izabranu sliku</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Image/Gui/Resources/translations/Image_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+94"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Napravi ravninu slike ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Napravi planarnu sliku u 3D prostoru</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation type="obsolete">stvoriti planarnu sliku u 3D prikazu</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-44"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Otvori ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Otvori pogled slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+326"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>nedefinirani tip boja za gledanje slika</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>Image pixel format</source>
      <translation>format slike u pixelima</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Odaberite orijentaciju</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation type="unfinished">Image plane</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY ravnina</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Ravnina</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Ravnina</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Obrnutim smjerom</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation type="unfinished">Odmak:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>Prilagodi sliku</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>rastegni sliku da odgovara prikazu</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>u mjerilu 1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Prikaz slike u mjerilu 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation type="obsolete"> I originalna boja</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation type="obsolete">Prikaži sliku s originalnim bojama</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation type="obsolete">I  Razvedri boju</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation type="obsolete">Prikaži sliku s s izbjeljenim bojama</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+13"/>
      <source>Ready...</source>
      <translation>Spreman...</translation>
    </message>
    <message>
      <location line="+375"/>
      <source>grey</source>
      <translation>siva</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zum</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>izvan slike</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation type="obsolete">Pregled slike</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+117"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Slike (*. png *. XPM *. jpg *. bmp)</translation>
    </message>
    <message>
      <location line="-99"/>
      <location line="+41"/>
      <location line="+57"/>
      <source>Choose an image file to open</source>
      <translation>Odaberite koju ce te sliku otvoriti</translation>
    </message>
    <message>
      <location line="-105"/>
      <location line="+41"/>
      <source>Images</source>
      <translation>Slike</translation>
    </message>
    <message>
      <location line="-36"/>
      <location line="+41"/>
      <source>All files</source>
      <translation>Sve datoteke</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error open image</source>
      <translation>Pogreška pri otvaranju slike</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the choosen image</source>
      <translation>Nije moguće učitati izabranu sliku</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
  </context>
</TS>
